# HurricaneDNS

## Install

```
pip install hurricanedns
```

## Requirements
 * python-html5lib
 * python-lxml
 * dnspython (optional - for importing BIND zones)

## Usage

Get the party started by logging in:

```
hurricanedns <he.net username> <he.net password>
```

You'll get dropped to a `hurricanedns` command prompt:

```
[user@dns.he.net]
```

Start with `help`.  You can always get specific help for a command by doing
`help [command]`.

To quit, use `exit`, `EOF`, or CTRL-D.
